@@ -680,4 +680,8 @@ class Interpreter:
                 print("Syntax error: command \"" + command[0] + "\" not recognized.")
 
 
-i = Interpreter()
+def start():
+    Interpreter()
+
+
+start()
